@@ -2,10 +2,9 @@ package KiokuDB::TypeMap::Entry::DBIC::ResultSet;
 BEGIN {
   $KiokuDB::TypeMap::Entry::DBIC::ResultSet::AUTHORITY = 'cpan:NUFFIN';
 }
-{
-  $KiokuDB::TypeMap::Entry::DBIC::ResultSet::VERSION = '1.21';
-}
+$KiokuDB::TypeMap::Entry::DBIC::ResultSet::VERSION = '1.23';
 use Moose;
+# ABSTRACT: KiokuDB::TypeMap::Entry for DBIx::Class::ResultSet objects
 
 use JSON;
 use Scalar::Util qw(weaken);
@@ -43,10 +42,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-KiokuDB::TypeMap::Entry::DBIC::ResultSet - L<KiokuDB::TypeMap::Entry> for
-L<DBIx::Class::ResultSet> objects
+KiokuDB::TypeMap::Entry::DBIC::ResultSet - KiokuDB::TypeMap::Entry for DBIx::Class::ResultSet objects
+
+=head1 VERSION
+
+version 1.23
 
 =head1 DESCRIPTION
 
@@ -55,10 +59,17 @@ simply serialized normally. This is the only L<DBIx::Class> related object that
 is literally stored in the database, as it represents a memory resident object,
 not a database resident one.
 
-=begin Pod::Coverage
+=for Pod::Coverage compile_collapse_body
 
-compile_collapse_body
+=head1 AUTHOR
 
-=end Pod::Coverage
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
